@@ -21,21 +21,22 @@ pub(crate) mod chunk_type;
 use crate::error::Error;
 use chunk_header::*;
 
+use anyhow::Result;
 use bytes::{Bytes, BytesMut};
 use std::marker::Sized;
 use std::{any::Any, fmt};
 
 pub(crate) trait Chunk: fmt::Display + fmt::Debug {
     fn header(&self) -> ChunkHeader;
-    fn unmarshal(raw: &Bytes) -> Result<Self, Error>
+    fn unmarshal(raw: &Bytes) -> Result<Self>
     where
         Self: Sized;
-    fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>;
-    fn check(&self) -> Result<(), Error>;
+    fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize>;
+    fn check(&self) -> Result<()>;
     fn value_length(&self) -> usize;
     fn as_any(&self) -> &(dyn Any + Send + Sync);
 
-    fn marshal(&self) -> Result<Bytes, Error> {
+    fn marshal(&self) -> Result<Bytes> {
         let capacity = CHUNK_HEADER_SIZE + self.value_length();
         let mut buf = BytesMut::with_capacity(capacity);
         self.marshal_to(&mut buf)?;
